foreach name [array names env STOOOP*] {unset env($name)}                                ;# reset any existing environment variables
set env(STOOOPCHECKDATA) 1
source stooop.tcl
namespace import stooop::*

### verify that object copying still works in member data checking mode

class a {}
proc a::a {this} {
    set ($this,n) 0
}
new [new a]

class A {
    proc A {this} {
        set ($this,n) 0
    }
}
new [new A]

class b {}
class b::c {}
proc b::c::c {this} {
    set ($this,n) 0
}
new [new b::c]

class B {
    class C {
        proc C {this} {
            set ($this,n) 0
        }
    }
    new [new C]
}
new [new B::C]
